@@ -1,10 +1,9 @@
 """
-ARENA-py
+arena-py
 
 Draw objects and run programs in the ARENA using Python!
 """
 
-__version__     = "0.1.44"
 __author__      = "CONIX Research Center"
 
 __license__     = "BSD 3-Clause"
