@@ -2,8 +2,11 @@ from .attribute import Attribute
 
 class JitsiVideo(Attribute):
     """
-    Jitsi Video Attribute. For video source.
+    JitsiVideo attribute class to manage its properties in the ARENA: Apply a jitsi video source to the geometry.
     Usage: jitsi_video=JitsiVideo(...)
+    
+    :param str displayName: ARENA or Jitsi display name of the video source; Will be ignored if jitsiId is given. (* change requires reload* ). (optional)
+    :param str jitsiId: JitsiId of the video source; If defined will override displayName. (optional)
     """
     def __init__(self, jitsiId=None, displayName=None):
         # Since jitsiId overrides displayName, do not set None arguments
