@@ -38,17 +38,18 @@ class ArenaAuth:
         self._mqtt_token = None
         self._id_token = None
 
-    def authenticate_user(self, host):
+    def authenticate_user(self, web_host):
         """
         Begins authentication flow, getting Google auth, opening web browser if
         needed, getting username and state from ARENA server.
-        host: The hostname of the ARENA webserver.
-        Returns: Username from arena-account, or None.
+
+        :param str web_host: The hostname of the ARENA webserver.
+        :return: Username from arena-account, or None.
         """
         print("Signing in to the ARENA...")
-        gauth_json = self._get_gauthid(host)
+        gauth_json = self._get_gauthid(web_host)
         creds = None
-        scene_auth_dir = self._get_scene_auth_path(host)
+        scene_auth_dir = self._get_scene_auth_path(web_host)
         scene_gauth_path = f"{scene_auth_dir}/{_gauth_file}"
 
         if not os.path.exists(scene_auth_dir):
@@ -77,26 +78,10 @@ class ArenaAuth:
                 session = AuthorizedSession(creds)
             else:
                 print("Requesting new Google authentication.")
-                if self._is_headless_client():
-                    # console flow for remote client
-                    flow = InstalledAppFlow.from_client_config(
-                        json.loads(gauth_json), self._scopes)
-                    creds = flow.run_console()
-                else:
-                    # automated browser flow for local client
-                    flow = InstalledAppFlow.from_client_config(
-                        json.loads(gauth_json), self._scopes)
-                    creds = flow.run_local_server(port=0)
-
-                    # # alternate, run console flow with browser popup
-                    # flow = InstalledAppFlow.from_client_config(
-                    #     json.loads(gauth_json), self._scopes, redirect_uri="urn:ietf:wg:oauth:2.0:oob")
-                    # auth_url, _ = flow.authorization_url(prompt="consent")
-                    # print("Please go to this URL: {}".format(auth_url))
-                    # webbrowser.open(auth_url, new=1, autoraise=True)
-                    # code = input("Enter the authorization code: ")
-                    # flow.fetch_token(code=code)
-                    # creds = flow.credentials
+                # automated browser flow for local client
+                flow = InstalledAppFlow.from_client_config(
+                    json.loads(gauth_json), self._scopes)
+                creds = flow.run_local_server(port=0)
 
                 session = flow.authorized_session()
             with open(scene_gauth_path, "wb") as token:
@@ -106,7 +91,7 @@ class ArenaAuth:
 
         username = None
         self._id_token = creds.id_token
-        user_info = self._get_user_state(host, self._id_token)
+        user_info = self._get_user_state(web_host, self._id_token)
         _user_info = json.loads(user_info)
         if "authenticated" in _user_info and "username" in _user_info:
             username = _user_info["username"]
@@ -116,22 +101,23 @@ class ArenaAuth:
             print(f"Authenticated Google account: {profile_info['email']}")
         return username
 
-    def authenticate_scene(self, host, realm, scene, username, video=False):
+    def authenticate_scene(self, web_host, realm, scene, username, video=False):
         """ End authentication flow, requesting permissions may change by owner
         or admin, for now, get a fresh mqtt_token each time.
-        host: The hostname of the ARENA webserver.
-        realm: The topic realm name.
-        scene: The namespace/scene name combination.
-        username: The ARENA username for the user.
-        video: If Jitsi video conference is requested.
-        Returns: username and mqtt_token from arena-account.
+
+        :param str web_host: The hostname of the ARENA webserver.
+        :param str realm: The topic realm name.
+        :param str scene: The namespace/scene name combination.
+        :param str username: The ARENA username for the user.
+        :param bool video: If Jitsi video conference is requested.
+        :return: username and mqtt_token from arena-account.
         """
-        scene_auth_dir = self._get_scene_auth_path(host)
+        scene_auth_dir = self._get_scene_auth_path(web_host)
         scene_mqtt_path = f"{scene_auth_dir}/{_mqtt_token_file}"
 
         print("Using remote-authenticated MQTT token.")
         mqtt_json = self._get_mqtt_token(
-            host, realm, scene, username, self._id_token, video)
+            web_host, realm, scene, username, self._id_token, video)
         # save mqtt_token
         with open(scene_mqtt_path, mode="w") as d:
             d.write(mqtt_json)
@@ -141,11 +127,11 @@ class ArenaAuth:
         self._log_token()
         return self._mqtt_token
 
-    def authenticate_device(self, host):
+    def authenticate_device(self, web_host):
         """
         Check for device mqtt_token, ask for a missing one, and save to local memory.
         """
-        device_auth_dir = self._get_device_auth_path(host)
+        device_auth_dir = self._get_device_auth_path(web_host)
         device_mqtt_path = f"{device_auth_dir}/{_mqtt_token_file}"
         # check token expiration
         _remove_credentials(device_auth_dir, expire=True)
@@ -159,7 +145,7 @@ class ArenaAuth:
             if not os.path.exists(device_auth_dir):
                 os.makedirs(device_auth_dir)
             print(
-                f"Generate a token for this device at https://{host}/user/profile")
+                f"Generate a token for this device at https://{web_host}/user/profile")
             mqtt_json = input(
                 "Paste auth MQTT full JSON here for this device: ")
             # save mqtt_token
@@ -171,32 +157,29 @@ class ArenaAuth:
         self._log_token()
         return self._mqtt_token
 
-    def _get_scene_auth_path(self, host):
-        return f"{_arena_user_dir}/python/{host}/s"
+    def has_publish_rights(self, token, topic):
+        """ Check the MQTT token for permission to publish to topic.
+        """
+        tok = jwt.decode(token, options={"verify_signature": False})
+        for pub in tok["publ"]:
+            if (topic.startswith(pub.strip().rstrip("/").rstrip("#"))):
+                return True
+        return False
 
-    def _get_device_auth_path(self, host):
-        return f"{_arena_user_dir}/python/{host}/d"
+    def _get_scene_auth_path(self, web_host):
+        return f"{_arena_user_dir}/python/{web_host}/s"
 
-    def get_writable_scenes(self, host):
+    def _get_device_auth_path(self, web_host):
+        return f"{_arena_user_dir}/python/{web_host}/d"
+
+    def get_writable_scenes(self, web_host):
         """ Request list of scene names for logged in user that user has publish permission for.
-        host: The hostname of the ARENA webserver.
-        Returns: list of scenes.
-        """
-        my_scenes = self._get_my_scenes(host, self._id_token)
-        return json.loads(my_scenes)
 
-    def _is_headless_client(self):
-        """ Determine headless or headed console.
+        :param str web_host: The hostname of the ARENA webserver.
+        :return: list of scenes.
         """
-        if "SSH_TTY" in os.environ or "SSH_CLIENT" in os.environ:
-            print("SSH connection detected, using headless auth.")
-            return True
-        try:
-            webbrowser.get()
-            return False
-        except (webbrowser.Error) as err:
-            print("Console-only OS detected. {0}".format(err))
-            return True
+        my_scenes = self._get_my_scenes(web_host, self._id_token)
+        return json.loads(my_scenes)
 
     def _log_token(self):
         """
@@ -227,8 +210,8 @@ class ArenaAuth:
     def check_local_auth(self):
         """
         Check for local mqtt_token and save to local memory.
-        TODO: remove local check after ARTS supports mqtt_token passing
         """
+        # TODO: remove local check after ARTS supports mqtt_token passing
         # 4 Oct 2021 remove deprecated user home creds path
         _remove_credentials(str(Path.home()))
         # check token expiration
@@ -244,11 +227,11 @@ class ArenaAuth:
             return self._mqtt_token
         return None
 
-    def _get_csrftoken(self, host):
+    def _get_csrftoken(self, web_host):
         # get the csrftoken for django
-        csrf_url = f"https://{host}/user/login"
+        csrf_url = f"https://{web_host}/user/login"
         client = requests.session()
-        client.get(csrf_url, verify=self.verify(host))  # sets cookie
+        client.get(csrf_url, verify=self.verify(web_host))  # sets cookie
         if "csrftoken" in client.cookies:
             self._csrftoken = client.cookies["csrftoken"]
         elif "csrf" in client.cookies:
@@ -257,32 +240,32 @@ class ArenaAuth:
             self._csrftoken = None
         return self._csrftoken
 
-    def _get_gauthid(self, host):
-        url = f"https://{host}/conf/gauth.json"
+    def _get_gauthid(self, web_host):
+        url = f"https://{web_host}/conf/gauth.json"
         return self.urlopen(url)
 
-    def _get_my_scenes(self, host, id_token):
-        url = f"https://{host}/user/my_scenes"
+    def _get_my_scenes(self, web_host, id_token):
+        url = f"https://{web_host}/user/my_scenes"
         if not self._csrftoken:
-            self._csrftoken = self._get_csrftoken(host)
+            self._csrftoken = self._get_csrftoken(web_host)
         params = {"id_token": id_token}
         query_string = parse.urlencode(params)
         data = query_string.encode("ascii")
         return self.urlopen(url, data=data, csrf=self._csrftoken)
 
-    def _get_user_state(self, host, id_token):
-        url = f"https://{host}/user/user_state"
+    def _get_user_state(self, web_host, id_token):
+        url = f"https://{web_host}/user/user_state"
         if not self._csrftoken:
-            self._csrftoken = self._get_csrftoken(host)
+            self._csrftoken = self._get_csrftoken(web_host)
         params = {"id_token": id_token}
         query_string = parse.urlencode(params)
         data = query_string.encode("ascii")
         return self.urlopen(url, data=data, csrf=self._csrftoken)
 
-    def _get_mqtt_token(self, host, realm, scene, username, id_token, video):
-        url = f"https://{host}/user/mqtt_auth"
+    def _get_mqtt_token(self, web_host, realm, scene, username, id_token, video):
+        url = f"https://{web_host}/user/mqtt_auth"
         if not self._csrftoken:
-            self._csrftoken = self._get_csrftoken(host)
+            self._csrftoken = self._get_csrftoken(web_host)
         params = {
             "id_auth": "google-installed",
             "username": username,
@@ -296,15 +279,15 @@ class ArenaAuth:
         data = query_string.encode("ascii")
         return self.urlopen(url, data=data, csrf=self._csrftoken)
 
-    def verify(self, host):
-        return host != "localhost"
+    def verify(self, web_host):
+        return web_host != "localhost"
 
     def urlopen(self, url, data=None, creds=False, csrf=None):
         """ urlopen is for ARENA URL connections.
-        url: the url to POST/GET.
-        data: None for GET, add params for POST.
-        creds: True to pass the MQTT token as a cookie.
-        csrf: The csrftoken.
+        :param str url: the url to POST/GET.
+        :param str data: None for GET, add params for POST.
+        :param bool creds: True to pass the MQTT token as a cookie.
+        :param str csrf: The csrftoken.
         """
         urlparts = urlsplit(url)
         try:
@@ -328,7 +311,7 @@ class ArenaAuth:
             if isinstance(err, HTTPError) and round(err.code, -2) == 400:
                 # user not authorized on website yet, they don"t have an ARENA username
                 base_url = "{0.scheme}://{0.netloc}".format(urlsplit(url))
-                print("Login with this this account on the website first:")
+                print("Login with this account on the website first:")
                 print(f"Trying to open login page: {base_url}/user")
                 try:
                     webbrowser.open_new_tab(f"{base_url}/user")
@@ -385,7 +368,11 @@ def permissions():
         f = open(mqtt_path, "r")
         mqtt_json = f.read()
         f.close()
-        mqtt_token = json.loads(mqtt_json)
+        try:
+            mqtt_token = json.loads(mqtt_json)
+        except (json.decoder.JSONDecodeError) as err:
+            print(f"{err}, {mqtt_path}")
+            continue
         mqtt_claims = jwt.decode(mqtt_token["token"], options={
             "verify_signature": False})
         _print_mqtt_token(mqtt_path, mqtt_claims)
@@ -404,7 +391,12 @@ def _remove_credentials(cred_dir, expire=False):
         f = open(test_mqtt_path, "r")
         mqtt_json = f.read()
         f.close()
-        mqtt_token = json.loads(mqtt_json)
+        try:
+            mqtt_token = json.loads(mqtt_json)
+        except (json.decoder.JSONDecodeError) as err:
+            print(f"{err}, {test_mqtt_path}")
+            os.remove(test_mqtt_path)
+            return
         mqtt_claims = jwt.decode(mqtt_token["token"], options={
             "verify_signature": False})
         exp = float(mqtt_claims["exp"])
