@@ -1,8 +1,10 @@
-from ..base_object import *
-from ..attributes import Animation, Data, Color
-from ..utils import *
 import uuid
 
+from ..base_object import *
+from ..attributes import Animation, Data, Position, Rotation, Scale, ATTRIBUTE_KEYWORD_TRANSLATION
+from ..utils import *
+
+
 class Object(BaseObject):
     """
     Object class. Defines a generic object in the ARENA.
@@ -42,6 +44,15 @@ class Object(BaseObject):
         if "object_type" not in kwargs:
             kwargs["object_type"] = Object.object_type
 
+        if "position" not in kwargs:
+            kwargs["position"] = Position(0,0,0)
+
+        if "rotation" not in kwargs:
+            kwargs["rotation"] = Rotation(0,0,0)
+
+        if "scale" not in kwargs:
+            kwargs["scale"] = Scale(1,1,1)
+
         # print warning if object is being created with the same id as an existing object
         if Object.exists(object_id):
             if not Object.get(object_id).persist:
@@ -67,6 +78,8 @@ class Object(BaseObject):
         # add current object to all_objects dict
         Object.add(self)
 
+        self.delayed_prop_tasks = {}  # dict of delayed property tasks
+
     def update_attributes(self, evt_handler=None, update_handler=None, **kwargs):
         if evt_handler:
             self.evt_handler = evt_handler
@@ -109,8 +122,8 @@ class Object(BaseObject):
 
     def json_preprocess(self, **kwargs):
         # kwargs are for additional param to add to json, like "action":"create"
-        json_payload = { k:v for k,v in vars(self).items() if k != "evt_handler" and \
-                                            k != "update_handler" and k != "animations" }
+        skipped_keys = ["evt_handler", "update_handler", "animations", "delayed_prop_tasks"]
+        json_payload = {k: v for k, v in vars(self).items() if k not in skipped_keys}
         json_payload.update(kwargs)
         return json_payload
 
@@ -139,34 +152,14 @@ class Object(BaseObject):
             # rotation should be in quaternions
             elif "rotation" == k:
                 rot = data["rotation"]
-                if rot.is_quaternion:
-                    json_data["rotation"] = rot
-                else:
-                    # remove w if euler
-                    rot_json = vars(rot).copy()
-                    del rot_json["w"]
-                    json_data["rotation"] = rot_json
+                # always publish quaternions on wire format to avoid persist euler->quat merges
+                json_data["rotation"] = rot.quaternion
 
-            # handle special case where "physics" should be "dynamic-body"
-            elif "physics" == k or "dynamic_body" == k:
-                json_data["dynamic-body"] = v
-
-            # handle special case where "clickable" should be "click-listener"
-            elif "clickable" == k or "click_listener" == k:
-                json_data["click-listener"] = v
-
-            # remove underscores from specific keys
-            elif "goto_url" == k:
-                json_data["goto-url"] = v
-
-            elif "jitsi_video" == k:
-                json_data["jitsi-video"] = v
-
-            elif "collision_listener" == k:
-                json_data["collision-listener"] = v
-
-            elif "animation_mixer" == k:
-                json_data["animation-mixer"] = v
+            elif "look_at" == k:
+                if isinstance(v, str):
+                    json_data["look-at"] = v
+                elif isinstance(v, Object):
+                    json_data["look-at"] = v.object_id
 
             # for animation, replace "start" and "end" with "from" and "to"
             elif isinstance(k, str) and "animation" == k[:len("animation")]:
@@ -174,9 +167,19 @@ class Object(BaseObject):
                 Utils.dict_key_replace(animation, "start", "from")
                 Utils.dict_key_replace(animation, "end", "to")
                 json_data[k] = animation
+
+            # Translate and remove underscores from any other keys.
+            # Must be done last since ATTRIBUTE_KEYWORD_TRANSLATION contains all attributes,
+            # which may interfere with special casing above from, say "rotation" for example.
+            elif k in ATTRIBUTE_KEYWORD_TRANSLATION:
+                json_data[ATTRIBUTE_KEYWORD_TRANSLATION[k]] = v
+
+            # allow: likely unknown/misspelled attribute to this library version
             else:
                 json_data[k] = v
 
+        json_payload.pop("delayed_prop_tasks", None)
+
         json_payload["data"] = json_data
         self.json_postprocess(json_payload, json_data)
         return self.json_encode(json_payload)
@@ -195,6 +198,9 @@ class Object(BaseObject):
     def remove(cls, obj):
         object_id = obj.object_id
         del Object.all_objects[object_id]
+        if (hasattr(obj, "delayed_prop_tasks")):
+            for task in obj.delayed_prop_tasks.values():  # Cancel all pending tasks
+                task.cancel()
 
     @classmethod
     def exists(cls, object_id):
