@@ -2,7 +2,10 @@ from .arena_object import Object
 
 class Icosahedron(Object):
     """
-    Class for Icosahedron in the ARENA.
+    Icosahedron object class to manage its properties in the ARENA: Icosahedron Geometry.
+    
+    :param int detail: detail (optional)
+    :param float radius: radius Defaults to '1' (optional)
     """
     object_type = "icosahedron"
 
